==> fuzzfetch-0.9.1.tar.gz: fuzzfetch-0.9.1/setup.py <==
#!/usr/bin/env python
# coding=utf-8
"""setuptools install script"""
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

from setuptools import setup


if __name__ == "__main__":
    setup(
        classifiers=[
            "Intended Audience :: Developers",
            "Topic :: Software Development :: Testing",
            "Topic :: Security",
            "License :: OSI Approved :: Mozilla Public License 2.0 (MPL 2.0)",
            "Programming Language :: Python :: 2",
            "Programming Language :: Python :: 2.7",
            "Programming Language :: Python :: 3",
            "Programming Language :: Python :: 3.4",
            "Programming Language :: Python :: 3.5",
            "Programming Language :: Python :: 3.6"
        ],
        description='Downloader for firefox/jsshell builds',
        entry_points={
            "console_scripts": ["fuzzfetch = fuzzfetch:Fetcher.main"]
        },
        install_requires=[
            "configparser>=3.5.0",
            "pytz",
            "requests"
        ],
        keywords="fuzz fuzzing security test testing",
        license="MPL 2.0",
        maintainer="Mozilla Fuzzing Team",
        maintainer_email="fuzzing@mozilla.com",
        name="fuzzfetch",
        package_dir={"": "src"},
        packages=["fuzzfetch"],
        url="https://github.com/MozillaSecurity/fuzzfetch",
        version="0.9.1")

==> fuzzfetch-0.9.3.tar.gz: fuzzfetch-0.9.3/setup.py <==
#!/usr/bin/env python
# coding=utf-8
"""setuptools install script"""
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.

from setuptools import setup


if __name__ == "__main__":
    setup(
        classifiers=[
            "Intended Audience :: Developers",
            "Topic :: Software Development :: Testing",
            "Topic :: Security",
            "License :: OSI Approved :: Mozilla Public License 2.0 (MPL 2.0)",
            "Programming Language :: Python :: 2",
            "Programming Language :: Python :: 2.7",
            "Programming Language :: Python :: 3",
            "Programming Language :: Python :: 3.4",
            "Programming Language :: Python :: 3.5",
            "Programming Language :: Python :: 3.6",
            "Programming Language :: Python :: 3.7"
        ],
        description='Downloader for firefox/jsshell builds',
        entry_points={
            "console_scripts": ["fuzzfetch = fuzzfetch:Fetcher.main"]
        },
        install_requires=[
            "backports.shutil_which; python_version < '3.3'",
            "configparser>=3.5.0",
            "pytz",
            "requests"
        ],
        keywords="fuzz fuzzing security test testing",
        license="MPL 2.0",
        maintainer="Mozilla Fuzzing Team",
        maintainer_email="fuzzing@mozilla.com",
        name="fuzzfetch",
        package_dir={"": "src"},
        packages=["fuzzfetch"],
        url="https://github.com/MozillaSecurity/fuzzfetch",
        version="0.9.3")
